#!/bin/sh
glilang=en

if [ "x$PROGNAME" = "x" ] ; then
    PROGNAME="Greenstone"
  if [ "$glilang" = "es" ]; then
    PROGFULLNAME="Biblioteca Digital Greenstone"
  elif [ "$glilang" = "fr" ]; then
    PROGFULLNAME="Bibliothcaire Greenstone"
  elif [ "$glilang" = "ru" ]; then
    PROGFULLNAME=" Greenstone"
  else
    PROGFULLNAME="Greenstone Digital Library"
  fi
  else
    PROGFULLNAME=$PROGNAME
fi

if [ "x$PROGABBR" = "x" ] ; then
    PROGABBR="GLI"
fi

if [ "x$PROGNAME_EN" = "x" ] ; then
    PROGNAME_EN="Greenstone Librarian Interface"
fi


echo
if [ "$glilang" = "es" ]; then
    echo "Interfaz de la $PROGFULLNAME ($PROGNAME_EN - $PROGABBR)"
    echo "Copyright (C) 2008, New Zealand Digital Library Project, University Of Waikato"
    echo "La Interfaz de la $PROGNAME NO INCLUYE ABSOLUTAMENTE NINGUNA GARANTA."
    echo "Para mayor informacin vea los trminos de la licencia en LICENSE.txt"
    echo "Este es un software abierto, por lo que lo invitamos a que lo distribuya de forma gratuita"
elif [ "$glilang" = "fr" ]; then
    echo "Interface du $PROGFULLNAME ($PROGNAME_EN - $PROGABBR)"
    echo "Copyright (C) 2008, New Zealand Digital Library Project, University Of Waikato"
    echo "$PROGABBR est fourni sans AUCUNE GARANTIE; pour des dtails, voir LICENSE.txt"
    echo "Ceci est un logiciel libre, et vous tes invit  le redistribuer"
elif [ "$glilang" = "ru" ]; then
    echo " $PROGFULLNAME ($PROGNAME_EN - $PROGABBR)"
    echo "Copyright (C) 2008, New Zealand Digital Library Project, University Of Waikato"
    echo "     ;  .   LICENSE.TXT"
    echo " -         "
else
    echo "$PROGNAME Librarian Interface ($PROGABBR)"
    echo "Copyright (C) 2008, New Zealand Digital Library Project, University Of Waikato"
    echo "$PROGABBR comes with ABSOLUTELY NO WARRANTY; for details see LICENSE.txt"
    echo "This is free software, and you are welcome to redistribute it"
fi
echo

##  -------- Run the Greenstone Librarian Interface --------

# This script must be run from within the directory in which it lives
thisdir=`pwd`
if [ ! -f "${thisdir}/client-gli.sh" ]; then
    if [ "$glilang" = "es" ]; then
        echo "Este guin deber ejecutarse desde el directorio en el que reside."
    elif [ "$glilang" = "fr" ]; then
	echo "Ce script doit tre excut  partir du rpertoire dans lequel il se trouve."
    elif [ "$glilang" = "ru" ]; then
	echo "      ,    "
    else
	echo "This script must be run from the directory in which it resides."
    fi
    exit 1
fi


## ---- Check Java exists ----
javapath=

# Some users may set the above line manually
if [ "x$javapath" = "x" ]; then

    # If it is set, use the JAVA_HOME environment variable
    if [ "x$JAVA_HOME" != "x" ]; then
	javapath="$JAVA_HOME/bin/java"

    # Check if Java is on the search path
    else
	javapath=`which java 2> /dev/null`
    fi
fi

# Check that a Java executable has been found
if [ "$glilang" = "es" ]; then
    echo "Revisando Java: $javapath"
elif [ "$glilang" = "fr" ]; then
    echo "Vrification de Java: $javapath"
elif [ "$glilang" = "ru" ]; then
    echo " Java: $javapath"
else
    echo "Checking Java: $javapath"
fi
if [ ! -x "$javapath" ]; then
    echo
    if [ "$glilang" = "es" ]; then
	echo "No se pudo localizar una versin apropiada de Java. Usted deber "
	echo "instalar un Ambiente de Ejecucin Java (versin 1.4 o superior) "
	echo "antes de correr la Interfaz de la $PROGFULLNAME                    ."
    elif [ "$glilang" = "fr" ]; then
	echo "Une version adquate de Java n'a pas pu tre localise."
	echo "Vous devez installer un Java Runtime Environment (version 1.4 ou"
	echo "suprieur) avant de dmarrer $PROGNAME Librarian Interface."
    elif [ "$glilang" = "ru" ]; then
	echo "      Java."
	echo "   Java Runtime Environment ( 1.4  )"
	echo "    $PROGNAME."
    else
	echo "Failed to locate an appropriate version of Java. You must install a"
	echo "Java Runtime Environment (version 1.4 or greater) before running the"
	echo "$PROGNAME Librarian Interface."
    fi
    exit 1
fi


## -- Check the version of Java is new enough (1.4.0 or higher) to run the GLI --
`$javapath -classpath . CheckJavaVersion > /dev/null`
if [ $? -ne 2 ] ; then
    echo
    if [ "$glilang" = "es" ]; then
	echo "La versin del Ambiente de Ejecucin Java (JRE por sus siglas en "
	echo "ingls) que usted tiene instalada es demasiado vieja para ejecutar "
	echo "la Interfaz de la Biblioteca Digital Greenstone. Por favor instale "
	echo "una nueva versin del Ambiente de Ejecucin Java (versin 1.4 o "
	echo "posterior) y ejecute nuevamente este guin."
    elif [ "$glilang" = "fr" ]; then
	echo "La version de Java Runtime Environment que vous avez installe est"
	echo "trop vielle pour faire fonctionner Greenstone Librarian Interface."
	echo "Veuillez installer une nouvelle version du JRE (version 1.4 ou plus"
	echo "rcente) et redmarrez le script."
    elif [ "$glilang" = "ru" ]; then
	echo " Java Runtime Environment,   ,  ,"
	echo "    Greenstone. , "
	echo "   JRE ( 1.4   ) "
	echo "  "
    else
	echo "The version of the Java Runtime Environment you have installed is too"
	echo "old to run the Greenstone Librarian Interface. Please install a new"
	echo "version of the JRE (version 1.4 or newer) and rerun this script."
    fi
    exit 1
fi

## ---- Check that the GLI has been compiled ----
if [ ! -f "classes/org/greenstone/gatherer/GathererProg.class" ] && [ ! -f "GLI.jar" ]; then
    echo
    if [ "$glilang" = "es" ]; then
	echo "Usted necesita compilar la Interfaz de la $PROGFULLNAME"
	echo "(por medio de makegli.sh) antes de ejecutar este guin."
    elif [ "$glilang" = "fr" ]; then
	echo "Vous devez compiler le $PROGNAME Interface (en utilisant makegli.sh)"
	echo "avant d'excuter ce script."
    elif [ "$glilang" = "ru" ]; then
	echo "     $PROGNAME"
	echo "( makegli.sh)    "
    else
	echo "You need to compile the $PROGNAME Librarian Interface (using makegli.sh)"
	echo "before running this script."
    fi
    exit 1
fi


## ---- Finally, run the GLI ----
echo
if [ "$glilang" = "es" ]; then
    echo "Ejecutando la Interfaz de la $PROGFULLNAME..."
elif [ "$glilang" = "fr" ]; then
    echo "Excution de $PROGNAME Librarian Interface"
elif [ "$glilang" = "ru" ]; then
    echo "   $PROGNAME..."
else
    echo "Running the $PROGNAME Librarian Interface..."
fi

# Other arguments you can provide to GLI to work around memory limitations, or debug
# -Xms<number>M    To set minimum memory (by default 32MB)
# -Xmx<number>M    To set maximum memory (by default the nearest 2^n to the total remaining physical memory)
# -verbose:gc      To set garbage collection messages
# -Xincgc          For incremental garbage collection (significantly slows performance)
# -Xprof           Function call profiling
# -Xloggc:<file>   Write garbage collection log

# GS2 only requires -classpath classes/:GLI.jar:lib/apache.jar:lib/qfslib.jar. GS3 requires more but it doesn't conflict with GS2:
$javapath -Xmx128M -classpath classes/:GLI.jar:lib/apache.jar:lib/qfslib.jar:lib/commons-codec-1.3.jar:lib/commons-httpclient-3.1-rc1.jar:lib/commons-logging-1.1.jar org.greenstone.gatherer.GathererProg -use_remote_greenstone $*

if [ "$glilang" = "es" ]; then
    echo "Hecho!"
elif [ "$glilang" = "fr" ]; then
    echo "Termin!"
elif [ "$glilang" = "ru" ]; then
    echo "!"
else
    echo "Done!"
fi