package org.greenstone.gatherer.util;

import java.io.Reader;
import java.io.IOException;

public class RemoveContentBeforeRootElementXMLReader extends Reader {

	static final byte[] xmlIndicator = "<?xml".getBytes();

	Reader ur;
	int foundBytesReturned = 0;
	boolean allFoundBytesReturned = false; //redundant, but may help performance


	public RemoveContentBeforeRootElementXMLReader( Reader ur ) {

		this.ur = ur;

		//read up to the xml indicator
		int foundBytes = 0;	
		char c = 0;
		while ( c != -1 ) {
			try {
				c = (char)ur.read();
			} catch( Exception e ) {
				System.err.println( "Exception while reading underlying Reader in RemoveContentBeforeRootElementXMLReader" );
			}

			if ( c == xmlIndicator[foundBytes] ) {
				foundBytes++;
			} else {
				System.out.print( c );
				foundBytes = 0;
			}

			if ( foundBytes == xmlIndicator.length ) {
				//System.out.println();
				return;
			}

		}
		System.err.println( "RemoveContentBeforeRootElementXMLReader:\n" +
			"The XML being loaded was did not contain the '<?xml' string as expected" );

	}

	public int read( char[] cbuf, int off, int len ) throws IOException {

		for ( int i=off; i<off+len && i<cbuf.length; i++ ) {

			//read from underlying reader
			int c = read();

			//catch end of stream
			if ( c == -1 ) {
				if ( i == off ) {
					return -1;
				}
				return i - off;
			}

			//insert character into the array
			cbuf[i] = (char)c;
		}
		return len;

	}

	public int read() throws IOException {

		if ( allFoundBytesReturned ) {
			return ur.read();
		}

		if ( foundBytesReturned < xmlIndicator.length ) {
			return xmlIndicator[foundBytesReturned++];
		}

		allFoundBytesReturned = true;
		return ur.read();
	}

	public void close() throws IOException {
		ur.close();
	}
}
